@@ -18,6 +18,7 @@
 
 import copy
 import netaddr
+from os_ken.ofproto import ether
 
 from faucet import valve_of
 from faucet import valve_acl
@@ -25,8 +26,6 @@ from faucet.valve_of import MATCH_FIELDS, OLD_MATCH_FIELDS
 from faucet.conf import Conf, test_config_condition, InvalidConfigError
 from faucet.valve_table import wildcard_table
 
-from ryu.ofproto import ether
-
 
 class ACL(Conf):
     """Contains the state for an ACL, including the configuration.
@@ -88,6 +87,7 @@ The output action contains a dictionary with the following elements:
         'output': (dict, list),
         'allow': int,
         'force_port_vlan': int,
+        'ct': dict,
     }
     output_actions_types = {
         'tunnel': dict,
@@ -100,6 +100,24 @@ The output action contains a dictionary with the following elements:
         'vlan_vid': int,
         'vlan_vids': list,
     }
+    ct_action_types = {
+        'flags': int,
+        'alg': int,
+        'table': int,
+        'zone': int,
+        'zone_src': int,
+        'clear': bool,
+        'nat': dict,
+    }
+    ct_action_nat_types = {
+        'flags': int,
+        'range_ipv4_min': str,
+        'range_ipv4_max': str,
+        'range_ipv6_min': str,
+        'range_ipv6_max': str,
+        'range_proto_min': int,
+        'range_proto_max': int
+    }
     tunnel_types = {
         'type': (str, None),
         'tunnel_id': (str, int, None),
@@ -151,11 +169,11 @@ The output action contains a dictionary with the following elements:
             test_config_condition(not isinstance(normalized_rule, dict), (
                 'ACL rule is %s not %s (%s)' % (type(normalized_rule), dict, rules)))
             conf['rules'].append(normalized_rule)
-        super(ACL, self).__init__(_id, dp_id, conf)
+        super().__init__(_id, dp_id, conf)
 
     def finalize(self):
         self._ports_resolved = True
-        super(ACL, self).finalize()
+        super().finalize()
 
     def check_config(self):
         test_config_condition(
@@ -187,6 +205,23 @@ The output action contains a dictionary with the following elements:
                                 # Old format
                                 self._check_conf_types(
                                     action_conf, self.output_actions_types)
+                        elif action_name == 'ct':
+                            self._check_conf_types(action_conf, self.ct_action_types)
+                            # if clear set, make sure nothing else is
+                            if 'clear' in action_conf and action_conf['clear']:
+                                test_config_condition(
+                                    len(action_conf) != 1,
+                                    "no other parameters can be set when 'clear' set on "
+                                    "conntrack ACL")
+                            else:
+                                test_config_condition(
+                                    'table' not in action_conf,
+                                    "required parameter 'table' not set for conntrack ACL")
+                                test_config_condition(
+                                    'zone' not in action_conf,
+                                    "required parameter 'zone' not set for conntrack ACL")
+                            if 'nat' in action_conf:
+                                self._check_conf_types(action_conf['nat'], self.ct_action_nat_types)
 
     def build(self, meters, vid, port_num):
         """Check that ACL can be built from config."""
@@ -200,7 +235,7 @@ The output action contains a dictionary with the following elements:
                     [self], wildcard_table,
                     [valve_of.goto_table(wildcard_table)],
                     [valve_of.goto_table(wildcard_table)],
-                    2**16-1, meters, self.exact_match,
+                    2**16 - 1, meters, self.exact_match,
                     vlan_vid=vid, port_num=port_num)
             except (netaddr.core.AddrFormatError, KeyError, ValueError) as err:
                 raise InvalidConfigError from err
@@ -398,18 +433,18 @@ The output action contains a dictionary with the following elements:
                 port = resolve_port_cb(port_name)
                 test_config_condition(
                     not port,
-                    ('ACL (%s) output port undefined in DP: %s'\
-                    % (self._id, self.dp_id))
-                    )
+                    ('ACL (%s) output port undefined in DP: %s'
+                     % (self._id, self.dp_id))
+                )
                 result[output_action] = port
             elif output_action == 'ports':
                 resolved_ports = [
                     resolve_port_cb(p) for p in output_action_values]
                 test_config_condition(
                     None in resolved_ports,
-                    ('ACL (%s) output port(s) not defined in DP: %s'\
-                    % (self._id, self.dp_id))
-                    )
+                    ('ACL (%s) output port(s) not defined in DP: %s'
+                     % (self._id, self.dp_id))
+                )
                 result[output_action] = resolved_ports
             elif output_action == 'failover':
                 failover = output_action_values
@@ -422,9 +457,9 @@ The output action contains a dictionary with the following elements:
                             resolve_port_cb(p) for p in failover_values]
                         test_config_condition(
                             None in resolved_ports,
-                            ('ACL (%s) failover port(s) not defined in DP: %s'\
-                            % (self._id, self.dp_id))
-                            )
+                            ('ACL (%s) failover port(s) not defined in DP: %s'
+                             % (self._id, self.dp_id))
+                        )
                         result[output_action][failover_name] = resolved_ports
                     else:
                         result[output_action][failover_name] = failover_values
@@ -447,9 +482,9 @@ The output action contains a dictionary with the following elements:
                         resolved_port = resolve_port_cb(action_conf)
                         test_config_condition(
                             resolved_port is None,
-                            ('ACL (%s) mirror port is not defined in DP: %s'\
-                            % (self._id, self.dp_id))
-                            )
+                            ('ACL (%s) mirror port is not defined in DP: %s'
+                             % (self._id, self.dp_id))
+                        )
                         resolved_actions[action_name] = resolved_port
                     elif action_name == 'output':
                         resolved_action = self._resolve_output_ports(
@@ -497,7 +532,8 @@ The output action contains a dictionary with the following elements:
                         rules.append(rule_conf)
         return rules
 
-    def does_rule_contain_tunnel(self, rule_conf):
+    @staticmethod
+    def does_rule_contain_tunnel(rule_conf):
         """Return true if the ACL rule contains a tunnel"""
         if 'actions' in rule_conf:
             if 'output' in rule_conf['actions']:
@@ -521,13 +557,14 @@ The output action contains a dictionary with the following elements:
                 return True
         return False
 
-    def _tunnel_source_id(self, source):
+    @staticmethod
+    def _tunnel_source_id(source):
         """Return ID for a tunnel source."""
         return tuple(sorted(source.items()))
 
-    def add_tunnel_source(self, dp, port, reverse=False, bi_directional=False):
+    def add_tunnel_source(self, dp_name, port, reverse=False, bi_directional=False):
         """Add a source dp/port pair for the tunnel ACL"""
-        source = {'dp': dp, 'port': port, 'reverse': reverse, 'bi_directional': bi_directional}
+        source = {'dp': dp_name, 'port': port, 'reverse': reverse, 'bi_directional': bi_directional}
         source_id = self._tunnel_source_id(source)
         self.tunnel_sources[source_id] = source
         for _id in self.tunnel_dests:
