@@ -19,10 +19,10 @@
 from faucet.faucet_metadata import EGRESS_METADATA_MASK
 
 
-class ValveTableConfig: # pylint: disable=too-few-public-methods,too-many-instance-attributes
+class ValveTableConfig:  # pylint: disable=too-many-instance-attributes
     """Configuration for a single table."""
 
-    def __init__(self, name, table_id, # pylint: disable=too-many-arguments
+    def __init__(self, name, table_id,  # pylint: disable=too-many-arguments
                  exact_match=None, meter=None, output=True, miss_goto=None,
                  size=None, match_types=None, set_fields=None, dec_ttl=None,
                  vlan_scale=None, vlan_port_scale=None,
@@ -80,14 +80,15 @@ def _fib_table(ipv, table_id):
         dec_ttl=True,
         vlan_port_scale=3.1,
         next_tables=_NEXT_VIP
-        )
+    )
+
 
 PORT_ACL_DEFAULT_CONFIG = ValveTableConfig(
     'port_acl',
     0,
     match_types=(('in_port', False),),
     next_tables=(('vlan',) + _NEXT_VIP)
-    )
+)
 VLAN_DEFAULT_CONFIG = ValveTableConfig(
     'vlan',
     PORT_ACL_DEFAULT_CONFIG.table_id + 1,
@@ -96,7 +97,7 @@ VLAN_DEFAULT_CONFIG = ValveTableConfig(
     set_fields=('vlan_vid',),
     vlan_port_scale=3,
     next_tables=('copro', 'vlan_acl', 'classification', 'eth_src')
-    )
+)
 COPRO_DEFAULT_CONFIG = ValveTableConfig(
     'copro',
     VLAN_DEFAULT_CONFIG.table_id + 1,
@@ -104,7 +105,7 @@ COPRO_DEFAULT_CONFIG = ValveTableConfig(
     vlan_port_scale=1.5,
     miss_goto='eth_dst',
     next_tables=(('eth_dst',)),
-    )
+)
 VLAN_ACL_DEFAULT_CONFIG = ValveTableConfig(
     'vlan_acl',
     VLAN_DEFAULT_CONFIG.table_id + 1,
@@ -114,7 +115,7 @@ CLASSIFICATION_DEFAULT_CONFIG = ValveTableConfig(
     VLAN_ACL_DEFAULT_CONFIG.table_id + 1,
     miss_goto='eth_src',
     next_tables=(('eth_src', 'ipv4_fib', 'ipv6_fib') + _NEXT_VIP)
-    )
+)
 ETH_SRC_DEFAULT_CONFIG = ValveTableConfig(
     'eth_src',
     CLASSIFICATION_DEFAULT_CONFIG.table_id + 1,
@@ -124,7 +125,7 @@ ETH_SRC_DEFAULT_CONFIG = ValveTableConfig(
                  ('in_port', False), ('vlan_vid', False)),
     set_fields=('vlan_vid', 'eth_dst'),
     vlan_port_scale=4.1,
-    )
+)
 IPV4_FIB_DEFAULT_CONFIG = _fib_table(4, ETH_SRC_DEFAULT_CONFIG.table_id + 1)
 IPV6_FIB_DEFAULT_CONFIG = _fib_table(6, IPV4_FIB_DEFAULT_CONFIG.table_id + 1)
 VIP_DEFAULT_CONFIG = ValveTableConfig(
@@ -134,7 +135,7 @@ VIP_DEFAULT_CONFIG = ValveTableConfig(
                  ('icmpv6_type', False), ('ip_proto', False)),
     next_tables=_NEXT_ETH,
     vlan_scale=8,
-    )
+)
 ETH_DST_HAIRPIN_DEFAULT_CONFIG = ValveTableConfig(
     'eth_dst_hairpin',
     VIP_DEFAULT_CONFIG.table_id + 1,
@@ -142,23 +143,23 @@ ETH_DST_HAIRPIN_DEFAULT_CONFIG = ValveTableConfig(
     miss_goto='eth_dst',
     exact_match=True,
     vlan_port_scale=4.1,
-    )
+)
 ETH_DST_DEFAULT_CONFIG = ValveTableConfig(
     'eth_dst',
     ETH_DST_HAIRPIN_DEFAULT_CONFIG.table_id + 1,
     exact_match=True,
-    miss_goto='flood', # Note: when using egress acls the miss goto will be
-                       # egress acl table
+    miss_goto='flood',  # Note: when using egress acls the miss goto will be
+                        # egress acl table
     match_types=(('eth_dst', False), ('vlan_vid', False)),
     next_tables=('egress', 'egress_acl'),
     vlan_port_scale=4.1,
     metadata_write=EGRESS_METADATA_MASK
-    )
+)
 EGRESS_ACL_DEFAULT_CONFIG = ValveTableConfig(
     'egress_acl',
     ETH_DST_DEFAULT_CONFIG.table_id + 1,
     next_tables=('egress',)
-    )
+)
 EGRESS_DEFAULT_CONFIG = ValveTableConfig(
     'egress',
     EGRESS_ACL_DEFAULT_CONFIG.table_id + 1,
@@ -167,13 +168,13 @@ EGRESS_DEFAULT_CONFIG = ValveTableConfig(
     next_tables=('flood',),
     miss_goto='flood',
     metadata_match=EGRESS_METADATA_MASK
-    )
+)
 FLOOD_DEFAULT_CONFIG = ValveTableConfig(
     'flood',
     EGRESS_DEFAULT_CONFIG.table_id + 1,
     match_types=(('eth_dst', True), ('in_port', False), ('vlan_vid', False)),
     vlan_port_scale=8.0,
-    )
+)
 MINIMUM_FAUCET_PIPELINE_TABLES = {
     'vlan', 'eth_src', 'eth_dst', 'flood'}
 
