@@ -20,9 +20,9 @@ import logging
 import random
 import time
 
-from ryu.lib import hub
-from ryu.ofproto import ofproto_v1_3 as ofp
-from ryu.ofproto import ofproto_v1_3_parser as parser
+from os_ken.lib import hub
+from os_ken.ofproto import ofproto_v1_3 as ofp
+from os_ken.ofproto import ofproto_v1_3_parser as parser
 
 from faucet.valve_of import devid_present
 from faucet.valve_of_old import OLD_MATCH_FIELDS
@@ -32,14 +32,14 @@ class GaugePoller:
     """Abstraction for a poller for statistics."""
 
     def __init__(self, conf, logname, prom_client):
-        self.dp = conf.dp # pylint: disable=invalid-name
+        self.dp = conf.dp  # pylint: disable=invalid-name
         self.conf = conf
         self.prom_client = prom_client
         self.reply_pending = False
         self.ryudp = None
         self.logger = logging.getLogger(
             logname + '.{0}'.format(self.conf.type)
-            )
+        )
         # _running indicates that the watcher is receiving data
         self._running = False
         self.req = None
@@ -47,7 +47,7 @@ class GaugePoller:
     def report_dp_status(self, dp_status):
         """Report DP status."""
         self.prom_client.dp_status.labels(
-            **dict(dp_id=hex(self.dp.dp_id), dp_name=self.dp.name)).set(dp_status) # pylint: disable=no-member
+            **dict(dp_id=hex(self.dp.dp_id), dp_name=self.dp.name)).set(dp_status)  # pylint: disable=no-member
 
     def start(self, ryudp, active):
         """Start the poller."""
@@ -72,13 +72,13 @@ class GaugePoller:
 
     def send_req(self):
         """Send a stats request to a datapath."""
-        raise NotImplementedError # pragma: no cover
+        raise NotImplementedError  # pragma: no cover
 
     def no_response(self):
         """Called when a polling cycle passes without receiving a response."""
 
         dpid_str = ''
-        if self.req and 'datapath' in self.req:
+        if self.req and hasattr(self.req, 'datapath'):
             dpid_str = 'DPID %s (%s)' % (self.req.datapath.id, hex(self.req.datapath.id))
 
         self.logger.info('%s no response to %s', dpid_str, self.req)
@@ -104,16 +104,13 @@ class GaugePoller:
         self.reply_pending = False
         self._update(rcv_time, msg)
 
-    @staticmethod
-    def _format_stat_pairs(_delim, _stat):
+    def _format_stat_pairs(self, _delim, _stat):  # pylint: disable=no-self-use
         return ()
 
-    @staticmethod
-    def _dp_stat_name(_stat, _stat_name):
+    def _dp_stat_name(self, _stat, _stat_name):  # pylint: disable=no-self-use
         return ''
 
-    @staticmethod
-    def _rcv_time(rcv_time):
+    def _rcv_time(self, rcv_time):  # pylint: disable=no-self-use
         return time.strftime('%b %d %H:%M:%S', time.localtime(rcv_time))
 
     def _update(self, rcv_time, msg):
@@ -125,7 +122,7 @@ class GaugePoller:
             for stat_name, stat_val in self._format_stat_pairs('-', stat):
                 dp_stat_name = self._dp_stat_name(stat, stat_name)
                 log_lines.append(self._update_line(rcv_time_str, dp_stat_name, stat_val))
-        with open(self.conf.file, 'a') as logfile:
+        with open(self.conf.file, 'a', encoding='utf-8') as logfile:
             logfile.writelines(log_lines)
 
     @staticmethod
@@ -134,7 +131,7 @@ class GaugePoller:
         for stat_name_list, stat_val in stat_pairs:
             stat_name = delim.join(stat_name_list)
             # OVS reports unsupported statistics as all-1-bits (UINT64_MAX)
-            if stat_val == 2**64-1:
+            if stat_val == 2**64 - 1:
                 stat_val = 0
             formatted_stats.append((stat_name, stat_val))
         return formatted_stats
@@ -155,20 +152,20 @@ class GaugeThreadPoller(GaugePoller):
     """
 
     def __init__(self, conf, logname, prom_client):
-        super(GaugeThreadPoller, self).__init__(conf, logname, prom_client)
+        super().__init__(conf, logname, prom_client)
         self.thread = None
         self.interval = self.conf.interval
         self.ryudp = None
 
     def start(self, ryudp, active):
         self.stop()
-        super(GaugeThreadPoller, self).start(ryudp, active)
+        super().start(ryudp, active)
         if active:
             self.thread = hub.spawn(self)
             self.thread.name = 'GaugeThreadPoller'
 
     def stop(self):
-        super(GaugeThreadPoller, self).stop()
+        super().stop()
         if self.is_active():
             hub.kill(self.thread)
             hub.joinall([self.thread])
@@ -194,7 +191,7 @@ class GaugeThreadPoller(GaugePoller):
 
     def send_req(self):
         """Send a stats request to a datapath."""
-        raise NotImplementedError # pragma: no cover
+        raise NotImplementedError  # pragma: no cover
 
 
 class GaugeMeterStatsPoller(GaugeThreadPoller):
@@ -280,8 +277,8 @@ class GaugePortStatePoller(GaugePoller):
 
     def send_req(self):
         """Send a stats request to a datapath."""
-        raise NotImplementedError # pragma: no cover
+        raise NotImplementedError  # pragma: no cover
 
     def no_response(self):
         """Called when a polling cycle passes without receiving a response."""
-        raise NotImplementedError # pragma: no cover
+        raise NotImplementedError  # pragma: no cover
